package t::DB::Row;
use Mouse v2.4.5;
extends qw/Aniki::Row/;

1;
__END__
